atomate.lammps.fireworks package — atomate 0.9.2 documentation

# atomate.lammps.fireworks package

## Submodules

## atomate.lammps.fireworks.core module

class `atomate.lammps.fireworks.core.` `LammpsFW`(lammps_input_set, input_filename='lammps.in', data_filename='lammps.data', lammps_cmd='lammps', db_file=None, parents=None, name='LammpsFW', log_filename='log.lammps', dump_filename=None, **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(lammps_input_set, input_filename='lammps.in', data_filename='lammps.data', lammps_cmd='lammps', db_file=None, parents=None, name='LammpsFW', log_filename='log.lammps', dump_filename=None, **kwargs)

    write lammps inputset, run, and store the output.

    Args:

      lammps_input_set (DictLammpsInput): lammps input set input_filename (str): input file name data_filename (str): data file name lammps_cmd (str): command to run lammps (skip the input file).

      > e.g. ‘mpirun -n 8 lmp_mpi’

      db_file (str): path to file specifying db credentials to place output parsing. parents ([Fireworks)]: parents of this particular Firework. name (str): descriptive name for lammps simulation log_filename (str) dump_filename (str) **kwargs: other kwargs that are passed to Firework.__init__.

class `atomate.lammps.fireworks.core.` `LammpsForceFieldFW`(input_file, final_molecule, forcefield, box_size, topologies=None, constituent_molecules=None, mols_number=None, user_settings=None, ff_site_property=None, input_filename='lammps.in', data_filename='lammps.data', lammps_cmd='lammps', db_file=None, parents=None, log_filename='log.lammps', dump_filenames=None, name='LammpsFFFW', **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(input_file, final_molecule, forcefield, box_size, topologies=None, constituent_molecules=None, mols_number=None, user_settings=None, ff_site_property=None, input_filename='lammps.in', data_filename='lammps.data', lammps_cmd='lammps', db_file=None, parents=None, log_filename='log.lammps', dump_filenames=None, name='LammpsFFFW', **kwargs)

    Write lammps input from forcefield and topology, run lammps, store results. Can be used with RunPackmol firework.

    Args:

      input_file (str): path to lammps input(or template) file. final_molecule (str/Molecule): either path to the moelcule of Molecule object. forcefield (ForceField): pymatgen.io.lammps.force_field.ForceField object box_size (list): list of list of low and high values for each dimension [[xlow, xhigh], …] topologies ([Topology]): list of pymatgen.io.lammps.topology.Topology objects, one for

      > each constituent molecule.

      constituent_molecules ([Molecule]): list of Molecule objects that make up the final_molecule mols_number (list): list of number of each constituent moelcule. user_settings (dict): ff_site_property (str): the site property used for forcefiled mapping input_filename (str): name of the input file to be written data_filename (str):name of the data file to be written lammps_cmd (str): lammps command run (without the input file) db_file (str): path to the db settings parents (list): list of Fireworks log_filename (str): lammps log file name dump_filenames (str): list of dump files name (str): firework name **kwargs:

class `atomate.lammps.fireworks.core.` `PackmolFW`(molecules, packing_config, tolerance=2.0, filetype='xyz', control_params=None, output_file='packed.xyz', copy_to_current_on_exit=False, site_property=None, parents=None, name='PackmolFW', packmol_cmd='packmol', **kwargs)

  Bases: `fireworks.core.firework.Firework`

  `__init__`(molecules, packing_config, tolerance=2.0, filetype='xyz', control_params=None, output_file='packed.xyz', copy_to_current_on_exit=False, site_property=None, parents=None, name='PackmolFW', packmol_cmd='packmol', **kwargs)
    Args:

      molecules (list): list of constituent molecules(Molecule objects) packing_config (list): list of dict config settings for each molecule in the

      > molecules list. eg: config settings for a single molecule [{“number”: 1, “inside box”:[0,0,0,100,100,100]}]

      tolerance (float): packmol tolerance filetype (string): input/output structure file type control_params (dict): packmol control parameters dictionary. Basically all parameters

      > other than structure/atoms.

      output_file (str): output file name. The extension will be adjusted according to the filetype. copy_to_current_on_exit (bool): whether or not to copy the packed molecule output file

      > to the current directory.

      site_property (str): the specified site property will be restored for the final Molecule object. parents ([Firework]): parent fireworks name (str): firework name packmol_cmd (str): path to packmol bin **kwargs:

## Module contents